##  Custom Calculations
You can configure your own calculations to define custom logic tailored to your needs. You can use calculation templates or start from scratch. To view code samples for typical use cases, see [Calculation Examples](https://help.sap.com/docs/leanix/ea/calculation-examples?locale=en-US&state=PRODUCTION&version=CLOUD "JavaScript code samples for common use cases.").
